"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
function ensureDirectoryExists(filePath) {
    if (fs.existsSync(filePath)) {
        return;
    }
    ensureDirectoryExists(path.dirname(filePath));
    fs.mkdirSync(filePath);
}
exports.ensureDirectoryExists = ensureDirectoryExists;
function ensureFileExists(filePath) {
    ensureDirectoryExists(path.dirname(filePath));
    fs.closeSync(fs.openSync(filePath, 'w'));
}
exports.ensureFileExists = ensureFileExists;
/**
 * Method to save a file on disk.
 *
 * @param filePath path where to
 * @param fileContent file contents
 */
function createFile(filePath, fileContent) {
    ensureFileExists(filePath);
    const writeStream = fs.createWriteStream(filePath);
    writeStream.write(fileContent);
}
exports.createFile = createFile;
//# sourceMappingURL=fileSystemHandler.js.map