"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const fsUtil = require("../../src/common/fileSystemHandler");
const sinon_1 = require("sinon");
const chai_1 = require("chai");
const path_1 = require("path");
const fs = require("fs");
const sb = sinon_1.createSandbox();
describe('File System Utils', () => {
    describe('ensureDirectoryExists', () => {
        let mkdirStub;
        let existsStub;
        beforeEach(() => {
            mkdirStub = sb.stub(fs, 'mkdirSync');
            existsStub = sb.stub(fs, 'existsSync');
        });
        afterEach(() => {
            sb.restore();
        });
        it('should return immediately if file or directory already exists', () => {
            const path = path_1.join('path', 'to', 'dir');
            existsStub.withArgs(path).returns(true);
            fsUtil.ensureDirectoryExists(path);
            chai_1.expect(mkdirStub.notCalled).to.be.true;
        });
        it('should create nested directories as needed', () => {
            const path = path_1.join('path', 'to');
            const path2 = path_1.join(path, 'dir');
            const path3 = path_1.join(path2, 'dir2');
            existsStub.returns(false);
            existsStub.withArgs(path).returns(true);
            fsUtil.ensureDirectoryExists(path3);
            chai_1.expect(mkdirStub.firstCall.args[0]).to.equal(path2);
            chai_1.expect(mkdirStub.secondCall.args[0]).to.equal(path3);
        });
    });
    describe('ensureFileExists', () => {
        afterEach(() => {
            sb.restore();
        });
        it('should ensure file exists', () => {
            const path = path_1.join('path', 'to', 'a', 'file.x');
            const closeStub = sb.stub(fs, 'closeSync');
            const openStub = sb.stub(fs, 'openSync');
            openStub.returns(123);
            const existsSyncStub = sb.stub(fs, 'existsSync').returns(true);
            fsUtil.ensureFileExists(path);
            chai_1.expect(existsSyncStub.calledBefore(openStub)).to.be.true;
            chai_1.expect(closeStub.firstCall.args[0]).to.equal(123);
        });
    });
});
//# sourceMappingURL=fileSystemHandler.test.js.map